@@ -785,12 +785,12 @@ class WebDriver(webdriver.Remote):
 
     # extend find element by name for backward compatibility testwa
     def find_element_by_name(self, name):
-        body = {'using': By.ACCESSIBILITY_ID, 'value': id, 'mode': 'byName'}
-        return self.execute(SeleniumCommand.FIND_ELEMENT, body)
+        body = {'using': By.ACCESSIBILITY_ID, 'value': name, 'mode': 'byName'}
+        return self.execute(SeleniumCommand.FIND_ELEMENT, body)['value']
 
     def find_elements_by_name(self, name):
-        body = {'using': By.ACCESSIBILITY_ID, 'value': id, 'mode': 'byName'}
-        return self.execute(SeleniumCommand.FIND_ELEMENTS, body)
+        body = {'using': By.ACCESSIBILITY_ID, 'value': name, 'mode': 'byName'}
+        return self.execute(SeleniumCommand.FIND_ELEMENTS, body)['value']
 
     # add checking points testwa
     def check_element_by_accessibility_id(self, id, note=None):
